import React, { lazy, Suspense } from "react";
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { AnalyticsProvider } from "@/contexts/AnalyticsContext";
import { GoogleAnalytics } from "@/components/analytics/GoogleAnalytics";
import { MicrosoftClarity } from "@/components/analytics/MicrosoftClarity";
import { AnalyticsWrapper } from "@/components/analytics/AnalyticsWrapper";
import { AuthGuard } from "@/components/auth/AuthGuard";
import { PageLoader } from "./components/common/PageLoader";
import { AdminLayout } from "./components/admin/AdminLayout";
import { StaticFileHandler } from "./components/StaticFileHandler";
import LoadingSpinner from '@/components/ui/loading-spinner';

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 5 * 60 * 1000, // 5 minutes
      refetchOnWindowFocus: false,
      refetchOnMount: false,
      refetchOnReconnect: false,
    },
  },
});

// Lazy loaded components
const Index = lazy(() => import("./pages/Index"));
const Categories = lazy(() => import("./pages/Categories"));
const CategoryPage = lazy(() => import("./pages/CategoryPage"));
const QuotePage = lazy(() => import("./pages/QuotePage"));
const About = lazy(() => import("./pages/About"));
const Contact = lazy(() => import("./pages/Contact"));
const FAQ = lazy(() => import("./pages/FAQ"));
const Privacy = lazy(() => import("./pages/Privacy"));
const Terms = lazy(() => import("./pages/Terms"));
const Auth = lazy(() => import("./pages/Auth"));
const Profile = lazy(() => import("./pages/Profile"));
const NotFound = lazy(() => import("./pages/NotFound"));
const AdminDashboard = lazy(() => import("./pages/admin/AdminDashboard"));
const AdminQuotes = lazy(() => import("./pages/admin/AdminQuotes"));
const AdminCategories = lazy(() => import("./pages/admin/AdminCategories"));
const AdminAuthors = lazy(() => import("./pages/admin/AdminAuthors"));
const AdminUsers = lazy(() => import("./pages/admin/AdminUsers"));
const AdminSettings = lazy(() => import("./pages/admin/AdminSettings"));
const AdminSEOPreview = lazy(() => import("./pages/admin/AdminSEOPreview"));
const AdminAnalytics = lazy(() => import("./pages/admin/AdminAnalytics"));
const Sitemap = lazy(() => import("./pages/Sitemap"));

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <AnalyticsProvider>
        <TooltipProvider>
          <Toaster />
          <Sonner />
          <BrowserRouter>
            <GoogleAnalytics />
            <MicrosoftClarity />
            <AnalyticsWrapper trackClicks={true} trackScrolling={true} trackFormInteractions={true}>
              <Suspense fallback={<LoadingSpinner />}>
                <Routes>
                  <Route path="/" element={<Index />} />
                  <Route path="/categories" element={<Categories />} />
                  <Route path="/categories/:categoryName" element={<CategoryPage />} />
                  <Route path="/quote/:id" element={<QuotePage />} />
                  <Route path="/about" element={<About />} />
                  <Route path="/contact" element={<Contact />} />
                  <Route path="/faq" element={<FAQ />} />
                  <Route path="/privacy" element={<Privacy />} />
                  <Route path="/terms" element={<Terms />} />
                  <Route path="/auth" element={<Auth />} />
                  <Route path="/sitemap" element={<Sitemap />} />
                  <Route
                    path="/profile"
                    element={
                      <AuthGuard>
                        <Profile />
                      </AuthGuard>
                    }
                  />
                  <Route
                    path="/admin"
                    element={
                      <AuthGuard>
                        <AdminLayout />
                      </AuthGuard>
                    }
                  >
                    <Route index element={<AdminDashboard />} />
                    <Route path="quotes" element={<AdminQuotes />} />
                    <Route path="categories" element={<AdminCategories />} />
                    <Route path="authors" element={<AdminAuthors />} />
                    <Route path="users" element={<AdminUsers />} />
                    <Route path="settings" element={<AdminSettings />} />
                    <Route path="seo-preview" element={<AdminSEOPreview />} />
                    <Route path="analytics" element={<AdminAnalytics />} />
                  </Route>
                  <Route path="*" element={<NotFound />} />
                </Routes>
              </Suspense>
            </AnalyticsWrapper>
          </BrowserRouter>
        </TooltipProvider>
      </AnalyticsProvider>
    </QueryClientProvider>
  );
}

export default App;
